.. _merger_tree:

Halo Merger Tree
================

.. note:: As of :code:`yt-3.0`, the halo merger tree functionality has been removed to be replaced by machinery that works with the ``HaloCatalog`` object.  In the mean time, this functionality can still be found in :code:`yt-2.x`.
